@@ -29,8 +29,8 @@ class CPEnv(Env):
         # self.X_val = np.load('dic_clfs.npy', allow_pickle=True).item()['xl3']
         # self.y_val = np.load('dic_clfs.npy', allow_pickle=True).item()['yl3']
 
-        # self.observation_space = (1, self.X_train.shape[1])
-        self.observation_space = spaces.Box(low=0, high=1, shape=(1, self.X_train.shape[1]), dtype=np.float32)
+        self.observation_space = (1, self.X_train.shape[1])
+        # self.observation_space = spaces.Box(low=0, high=1, shape=(1, self.X_train.shape[1]), dtype=np.float32)
         print("self.observation_space=", self.observation_space)
         self.action_space = spaces.Discrete(2)
         # self.action_space = spaces.MultiDiscrete([2] * self.hangshu)
@@ -44,12 +44,12 @@ class CPEnv(Env):
         self.right_nums = 0
 
         num = time.time()
-        seed = float(str(num).split(".")[1])
-        seed = int(seed)
-        # print("此次种子为：",seed)
+        snd = float(str(num).split(".")[1])
+        snd = int(snd)
+        # print("此次种子为：",snd)
         self.shunxu = np.arange(0, self.X_train.shape[0])
         # print(self.shunxu)
-        np.random.seed(seed)
+        np.random.seed(snd)
         np.random.shuffle(self.shunxu)
         # print(self.shunxu)
         self.X_train = self.X_train[self.shunxu]
